@@ -1,10 +1,6 @@
-from __future__ import annotations
-
 from django.db import models
 from django.test import TestCase
-
-from django_fsm import FSMField
-from django_fsm import transition
+from django_fsm import FSMField, transition
 from django_fsm.signals import post_transition
 
 
@@ -20,7 +16,7 @@ class TestModel(models.Model):
         self.counter += 1
 
     class Meta:
-        app_label = "testapp"
+        app_label = 'testapp'
 
 
 def count_calls(sender, instance, name, source, target, **kwargs):
